pub struct CycleTime { /* private fields */ }Expand description
Represents a moment in time with both monotonic and wall clock components.
This structure captures a specific point in time using:
instant: Monotonic time for measuring durations and intervalssystem_time: Wall clock time for timestamps and human-readable times
Implementations
Sourceimpl CycleTime
impl CycleTime
Sourcepub fn new(instant: Instant, system_time: OffsetDateTime) -> Self
pub fn new(instant: Instant, system_time: OffsetDateTime) -> Self
Create a new TriggerTime with the given instant and system time
pub const fn now(&self) -> Instant
pub const fn unix_timestamp(&self) -> OffsetDateTime
pub const fn unix_timestamp_nanos(&self) -> i128