ExecutorState

Enum ExecutorState 

pub enum ExecutorState {
    Running,
    Terminated,
}
Indicates whether the executor should continue running or terminate.

Returned by the main execution cycle to signal the runtime’s desired state.

Variants



Running

The executor should continue processing cycles



Terminated

The executor should shut down gracefully (triggered by Control::Terminate)

Implementations

Source

impl ExecutorState

pub fn is_running(&self) -> bool

Returns true if this is a ExecutorState::Running, otherwise false

pub fn is_terminated(&self) -> bool

Returns true if this is a ExecutorState::Terminated, otherwise false