RuntimeBuilder

Struct RuntimeBuilder 

pub struct RuntimeBuilder<C: Clock, M: ExecutionMode> { /* private fields */ }
Builder for constructing a runtime with specific clock and execution mode.

Uses the type system to ensure both clock and execution mode are provided before building the runtime.

Implementations

Source

impl<C: Clock, M: ExecutionMode> RuntimeBuilder<C, M>

pub const fn new() -> Self

pub fn with_clock(self, clock: C) -> Self

pub fn with_mode(self, mode: M) -> Self

pub fn build(self) -> Result<Runtime<C, M>, RuntimeBuilderError>