Module clock
Source - CycleTime
- Represents a moment in time with both monotonic and wall clock components.
- Duration
- A span of time with nanosecond precision.
- HistoricalClock
- A clock that replays historical time by walking through a specified interval.
- Interval
- Represents a time interval with an inclusive start and exclusive end.
- OffsetDateTime
- A
PrimitiveDateTime with a UtcOffset. - PrecisionClock
- A high-precision clock that combines wall time accuracy with monotonic performance.
- TestClock
- A clock implementation for testing that starts at a baseline and advances from there.
- Clock
- Provides timing information for execution contexts.