pub struct RuntimeBuilder<C: Clock, M: ExecutionMode> { /* private fields */ }Expand description
Builder for constructing a runtime with specific clock and execution mode.
Uses the type system to ensure both clock and execution mode are provided before building the runtime.
Implementations
Sourceimpl<C: Clock, M: ExecutionMode> RuntimeBuilder<C, M>
impl<C: Clock, M: ExecutionMode> RuntimeBuilder<C, M>